%?mingw_package_header

%global svn_revision 2215
%global svn_stamp 20130517

Summary:        Almost Native Graphics Layer Engine
Name:           mingw-angleproject
Version:        0
Release:        %mkrel 0.7.svn%{svn_revision}.%{svn_stamp}.5
License:        BSD
Group:          Development/Other
URL:            http://code.google.com/p/angleproject/

# Upstream hasn't done any official releases yet
# To generate snapshot:
# svn checkout http://angleproject.googlecode.com/svn/trunk/ angleproject
# tar --exclude-vcs -cjvpf angleproject-r$(svnversion angleproject).tar.bz2 angleproject
Source:         angleproject-r%{svn_revision}.tar.bz2

BuildRequires:  mingw32-filesystem >= 95
BuildRequires:  mingw64-filesystem >= 95
BuildRequires:  mingw32-gcc-c++
BuildRequires:  mingw64-gcc-c++

BuildRequires:  gyp

BuildArch:      noarch

# File names are case-sensitive on Linux
Patch0:         angleproject-fix-case-sensitive-include.patch

# Make sure an import library is created and the correct .def file is used during the build
Patch2:         angleproject-include-import-library-and-use-def-file.patch

# .def pieces taken from http://qt.gitorious.org/qt/qtbase/commit/b2c44985e740d0a0ea86b7b9f4cc849258ac2340
Patch3:         angleproject-fix-mingw-compatibility.patch

# http://qt.gitorious.org/qt/qtbase/commit/dc2bfb6f8977732e1cd5ed9faac5a32870e2967a
# Fix typedefs for Win64
# The long int type is incorrect for Windows 64-bit as LLP64 is used there.
Patch4:         angleproject-fix-typedefs-for-win64.patch

# WebKit depends on symbols which are used in the static library called translator_hlsl
# This static library is linked into the libGLESv2 shared library
# To allow building WebKit export the required symbols in the libGLESv2 shared library
Patch5:         angleproject-export-shader-symbols.patch


%description
ANGLE is a conformant implementation of the OpenGL ES 2.0 specification that
is hardware‐accelerated via Direct3D. ANGLE v1.0.772 was certified compliant
by passing the ES 2.0.3 conformance tests in October 2011. ANGLE also provides
an implementation of the EGL 1.4 specification.

ANGLE is used as the default WebGL backend for both Google Chrome and
Mozilla Firefox on Windows platforms. Chrome uses ANGLE for all graphics
rendering on Windows, including the accelerated Canvas2D implementation
and the Native Client sandbox environment.

Portions of the ANGLE shader compiler are used as a shader validator and
translator by WebGL implementations across multiple platforms. It is used
on Mac OS X, Linux, and in mobile variants of the browsers. Having one shader
validator helps to ensure that a consistent set of GLSL ES shaders are
accepted across browsers and platforms. The shader translator can be used
to translate shaders to other shading languages, and to optionally apply
shader modifications to work around bugs or quirks in the native graphics
drivers. The translator targets Desktop GLSL, Direct3D HLSL, and even ESSL
for native GLES2 platforms.


%?mingw_debug_package


# Win32
%package -n mingw32-angleproject
Summary:        Almost Native Graphics Layer Engine for Win32
Group:          Development/Other

%description -n mingw32-angleproject
ANGLE is a conformant implementation of the OpenGL ES 2.0 specification that
is hardware‐accelerated via Direct3D. ANGLE v1.0.772 was certified compliant
by passing the ES 2.0.3 conformance tests in October 2011. ANGLE also provides
an implementation of the EGL 1.4 specification.

ANGLE is used as the default WebGL backend for both Google Chrome and
Mozilla Firefox on Windows platforms. Chrome uses ANGLE for all graphics
rendering on Windows, including the accelerated Canvas2D implementation
and the Native Client sandbox environment.

Portions of the ANGLE shader compiler are used as a shader validator and
translator by WebGL implementations across multiple platforms. It is used
on Mac OS X, Linux, and in mobile variants of the browsers. Having one shader
validator helps to ensure that a consistent set of GLSL ES shaders are
accepted across browsers and platforms. The shader translator can be used
to translate shaders to other shading languages, and to optionally apply
shader modifications to work around bugs or quirks in the native graphics
drivers. The translator targets Desktop GLSL, Direct3D HLSL, and even ESSL
for native GLES2 platforms.

%package -n mingw32-angleproject-static
Summary:       Static version of the mingw32-angleproject library
Requires:      mingw32-angleproject = %{version}-%{release}
BuildArch:     noarch

%description -n mingw32-angleproject-static
Static version of the mingw32-angleproject library.

# Win64
%package -n mingw64-angleproject
Summary:        Almost Native Graphics Layer Engine for Win64
Group:          Development/Other

%description -n mingw64-angleproject
ANGLE is a conformant implementation of the OpenGL ES 2.0 specification that
is hardware‐accelerated via Direct3D. ANGLE v1.0.772 was certified compliant
by passing the ES 2.0.3 conformance tests in October 2011. ANGLE also provides
an implementation of the EGL 1.4 specification.

ANGLE is used as the default WebGL backend for both Google Chrome and
Mozilla Firefox on Windows platforms. Chrome uses ANGLE for all graphics
rendering on Windows, including the accelerated Canvas2D implementation
and the Native Client sandbox environment.

Portions of the ANGLE shader compiler are used as a shader validator and
translator by WebGL implementations across multiple platforms. It is used
on Mac OS X, Linux, and in mobile variants of the browsers. Having one shader
validator helps to ensure that a consistent set of GLSL ES shaders are
accepted across browsers and platforms. The shader translator can be used
to translate shaders to other shading languages, and to optionally apply
shader modifications to work around bugs or quirks in the native graphics
drivers. The translator targets Desktop GLSL, Direct3D HLSL, and even ESSL
for native GLES2 platforms.

%package -n mingw64-angleproject-static
Summary:       Static version of the mingw32-angleproject library
Requires:      mingw64-angleproject = %{version}-%{release}
BuildArch:     noarch

%description -n mingw64-angleproject-static
Static version of the mingw64-angleproject library.


%prep
%setup -q -n angleproject
%patch0 -p0
%patch2 -p0
%patch3 -p0
%patch4 -p4
%patch5 -p0


%build
# This project uses the gyp build system and various
# hacks are required to get this project built.
# Therefore the regular Fedora MinGW RPM macros
# can't be used for this package

# The gyp build system always uses the environment variable RPM_OPT_FLAGS when it's set
# For MinGW we don't want this, so unset this environment variable
unset RPM_OPT_FLAGS

for target in win32 win64 ; do
    mkdir build_$target
    pushd build_$target
        if [ "$target" = "win32" ] ; then
            export CXX=%{mingw32_cxx}
            export AR=%{mingw32_ar}
        else
            export CXX=%{mingw64_cxx}
            export AR=%{mingw64_ar}
        fi

        gyp -D OS=win -D TARGET=$target --depth . -I ../build/common.gypi ../src/build_angle.gyp

        # Make sure the correct libraries are linked in
        sed -i s@'^LIBS :='@'LIBS := -ld3d9'@ ../src/libGLESv2.target.mk
        sed -i s@'^LIBS :='@'LIBS := -ld3d9 -ldxguid -L. -lGLESv2'@ ../src/libEGL.target.mk

        make %{?_smp_mflags} V=1 CXXFLAGS="-std=c++11 -msse2 -DUNICODE -D_UNICODE"

        # Also build static libraries (which are needed by the static Qt build)
        ${AR} rcs libGLESv2.a out/Debug/obj.target/libGLESv2/../src/common/debug.o out/Debug/obj.target/libGLESv2/../src/common/RefCountObject.o \
            out/Debug/obj.target/libGLESv2/../src/libGLESv2/IndexDataManager.o out/Debug/obj.target/libGLESv2/../src/libGLESv2/VertexDataManager.o \
            out/Debug/obj.target/libGLESv2/../src/libGLESv2/Blit.o out/Debug/obj.target/libGLESv2/../src/libGLESv2/Buffer.o \
            out/Debug/obj.target/libGLESv2/../src/libGLESv2/Context.o out/Debug/obj.target/libGLESv2/../src/libGLESv2/D3DConstantTable.o \
            out/Debug/obj.target/libGLESv2/../src/libGLESv2/Fence.o out/Debug/obj.target/libGLESv2/../src/libGLESv2/Float16ToFloat32.o \
            out/Debug/obj.target/libGLESv2/../src/libGLESv2/Framebuffer.o out/Debug/obj.target/libGLESv2/../src/libGLESv2/HandleAllocator.o \
            out/Debug/obj.target/libGLESv2/../src/libGLESv2/libGLESv2.o out/Debug/obj.target/libGLESv2/../src/libGLESv2/main.o \
            out/Debug/obj.target/libGLESv2/../src/libGLESv2/Program.o out/Debug/obj.target/libGLESv2/../src/libGLESv2/ProgramBinary.o \
            out/Debug/obj.target/libGLESv2/../src/libGLESv2/Query.o out/Debug/obj.target/libGLESv2/../src/libGLESv2/Renderbuffer.o \
            out/Debug/obj.target/libGLESv2/../src/libGLESv2/ResourceManager.o out/Debug/obj.target/libGLESv2/../src/libGLESv2/Shader.o \
            out/Debug/obj.target/libGLESv2/../src/libGLESv2/Texture.o out/Debug/obj.target/libGLESv2/../src/libGLESv2/TextureSSE2.o \
            out/Debug/obj.target/libGLESv2/../src/libGLESv2/utilities.o out/Debug/obj.target/../src/libtranslator_hlsl.a \
            out/Debug/obj.target/../src/libtranslator_common.a out/Debug/obj.target/../src/libpreprocessor.a 
        ${AR} rcs libEGL.a out/Debug/obj.target/libEGL/../src/common/debug.o out/Debug/obj.target/libEGL/../src/common/RefCountObject.o \
            out/Debug/obj.target/libEGL/../src/libEGL/Config.o out/Debug/obj.target/libEGL/../src/libEGL/Display.o \
            out/Debug/obj.target/libEGL/../src/libEGL/libEGL.o out/Debug/obj.target/libEGL/../src/libEGL/main.o \
            out/Debug/obj.target/libEGL/../src/libEGL/Surface.o
    popd
done


%install
# The gyp build system doesn't know how to install files
# and gives libraries invalid filenames.. *sigh*
mkdir -p $RPM_BUILD_ROOT%{mingw32_bindir} $RPM_BUILD_ROOT%{mingw32_libdir} $RPM_BUILD_ROOT%{mingw32_includedir}
mkdir -p $RPM_BUILD_ROOT%{mingw64_bindir} $RPM_BUILD_ROOT%{mingw64_libdir} $RPM_BUILD_ROOT%{mingw64_includedir}

install build_win32/out/Debug/src/libGLESv2.so $RPM_BUILD_ROOT%{mingw32_bindir}/libGLESv2.dll
install build_win64/out/Debug/src/libGLESv2.so $RPM_BUILD_ROOT%{mingw64_bindir}/libGLESv2.dll

install build_win32/out/Debug/src/libEGL.so $RPM_BUILD_ROOT%{mingw32_bindir}/libEGL.dll
install build_win64/out/Debug/src/libEGL.so $RPM_BUILD_ROOT%{mingw64_bindir}/libEGL.dll

install -m0644 build_win32/libGLESv2.dll.a build_win32/libGLESv2.a $RPM_BUILD_ROOT%{mingw32_libdir}
install -m0644 build_win64/libGLESv2.dll.a build_win64/libGLESv2.a $RPM_BUILD_ROOT%{mingw64_libdir}

install -m0644 build_win32/libEGL.dll.a build_win32/libEGL.a $RPM_BUILD_ROOT%{mingw32_libdir}
install -m0644 build_win64/libEGL.dll.a build_win64/libEGL.a $RPM_BUILD_ROOT%{mingw64_libdir}

cp -Rv include/* $RPM_BUILD_ROOT%{mingw32_includedir}
cp -Rv include/* $RPM_BUILD_ROOT%{mingw64_includedir}


%files -n mingw32-angleproject
%doc LICENSE
%{mingw32_bindir}/libEGL.dll
%{mingw32_bindir}/libGLESv2.dll
%{mingw32_includedir}/EGL
%{mingw32_includedir}/GLES2
%{mingw32_includedir}/GLSLANG
%{mingw32_includedir}/KHR
%{mingw32_libdir}/libEGL.dll.a
%{mingw32_libdir}/libGLESv2.dll.a

%files -n mingw32-angleproject-static
%{mingw32_libdir}/libEGL.a
%{mingw32_libdir}/libGLESv2.a

%files -n mingw64-angleproject
%doc LICENSE
%{mingw64_bindir}/libEGL.dll
%{mingw64_bindir}/libGLESv2.dll
%{mingw64_includedir}/EGL  
%{mingw64_includedir}/GLES2  
%{mingw64_includedir}/GLSLANG  
%{mingw64_includedir}/KHR
%{mingw64_libdir}/libEGL.dll.a
%{mingw64_libdir}/libGLESv2.dll.a

%files -n mingw64-angleproject-static
%{mingw64_libdir}/libEGL.a
%{mingw64_libdir}/libGLESv2.a




%changelog
* Sat Feb 06 2016 umeabot <umeabot> 0-0.7.svn2215.20130517.5.mga6
+ Revision: 941361
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 0-0.7.svn2215.20130517.4.mga5
+ Revision: 750508
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0-0.7.svn2215.20130517.3.mga5
+ Revision: 682404
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 0-0.7.svn2215.20130517.2.mga4
+ Revision: 536154
- Mageia 4 Mass Rebuild

* Sun Sep 22 2013 neoclust <neoclust> 0-0.7.svn2215.20130517.1.mga4
+ Revision: 483410
- imported package mingw-angleproject


* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0-0.7.svn2215.20130517
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sat May 18 2013 Erik van Pienbroek <epienbro@fedoraproject.org> - 0-0.6.svn2215.20130517
- Export various symbols from the hlsl translator static library in the
  libGLESv2.dll shared library as they are needed by mingw-qt5-qtwebkit.
  The symbols in question are marked as NONAME (hidden)

* Fri May 17 2013 Erik van Pienbroek <epienbro@fedoraproject.org> - 0-0.5.svn2215.20130517
- Update to 20130517 snapshot (r2215)

* Thu Apr  4 2013 Erik van Pienbroek <epienbro@fedoraproject.org> - 0-0.4.svn1561.20121214
- Added another workaround due to the fact that the gyp
  build system doesn't properly support cross-compilation
  Fixes FTBFS against latest gyp

* Fri Jan 25 2013 Erik van Pienbroek <epienbro@fedoraproject.org> - 0-0.3.svn1561.20121214
- Added license
- Resolved various rpmlint warnings
- Prefix the release tag with '0.'

* Mon Dec 24 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 0-0.2.svn1561.20121214
- Added -static subpackages

* Fri Dec 21 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 0-0.1.svn1561.20121214
- Initial release

